@@ -5,43 +5,41 @@ import shutil
 import sys
 import tempfile
 from datetime import datetime
-from .ext_exception import ExtException
 
-from .version import __version__
 from . import helper
 from .container_reader import extract as container_extract, decompress_and_extract
 from .container_writer import build as container_build, compress_and_build
 from .decoder import decode, encode
+from .ext_exception import ExtException
 from .file_organizer import FileOrganizer
 from .file_organizer_ce import FileOrganizerCE
+from .helper import update_dict
 from .index import update_index
 from .json_container_decoder import json_decode, json_encode
-from .helper import update_dict
+from .version import __version__
+
+
+def _load_json(filename):
+    try:
+        with open(filename, 'r', encoding='utf-8') as f:
+            data = json.load(f)
+        if not isinstance(data, dict):
+            raise Exception(f'Index file not dict ({filename})\n')
+        return data
+    except FileNotFoundError:
+        raise Exception(f'Index file not found ({filename})')
+    except Exception as err:
+        raise Exception(f'Bad index file ({filename}) - {err}\n')
 
 
 def _check_index(index_filename):
-    def load_json(filename):
-        try:
-            with open(filename, 'r', encoding='utf-8') as f:
-                data = json.load(f)
-            if not isinstance(data, dict):
-                print(f'Error: Bad index file - not dict\n')
-                return False
-            return data
-        except FileNotFoundError:
-            print(f'Error: index file not found - {index}')
-            return False
-        except Exception as err:
-            print(f'Error: Bad index file - {err}\n')
-            return False
-
     if index_filename:
         index = []
-        _index = load_json(index_filename)
+        _index = _load_json(index_filename)
         sub_index = _index.pop('index.json', None)
         if sub_index:
             for elem in sub_index:
-                index.append(load_json(elem))
+                index.append(_load_json(elem))
         index.append(_index)
         data = update_dict(*index)
         return data
@@ -82,7 +80,7 @@ def extract(in_filename: str, out_dir_name: str, *, temp_dir=None, index=None, v
         decode(dir_stage2, dir_stage3, pool=pool, version=version)
 
         if descent:
-            FileOrganizerCE.unpack(dir_stage3, out_dir_name, pool=pool, index=index, descent=descent)
+            FileOrganizerCE.unpack(dir_stage3, out_dir_name, pool=pool, index=index, descent=int(descent))
         else:
             FileOrganizer.unpack(dir_stage3, out_dir_name, pool=pool, index=index)
 
@@ -124,7 +122,7 @@ def build(in_dir_name: str, out_file_name: str, *, temp_dir=None, index=None,
         pool = helper.get_pool(processes=1)
 
         if descent:
-            FileOrganizerCE.pack(in_dir_name, dir_stage3, pool=pool, index=index, descent=descent)
+            FileOrganizerCE.pack(in_dir_name, dir_stage3, pool=pool, index=index, descent=int(descent))
         else:
             FileOrganizer.pack(in_dir_name, dir_stage3, pool=pool, index=index)
 
@@ -148,6 +146,70 @@ def build(in_dir_name: str, out_file_name: str, *, temp_dir=None, index=None,
         print(f'\n\n{error}')
 
 
+def build_all(product_file_name: str, product_code: str = None):
+    try:
+        products = _load_json(os.path.abspath(product_file_name))
+        if product_code:
+            products = {product_code: products[product_code]}
+            products[product_code]['disable'] = False
+        for product, params in products.items():
+            if params.get('disable'):
+                continue
+            print(f'\nСобираем {product}')
+            build(
+                params['src'], params['bin'],
+                temp_dir=params.get('temp'), index=params.get('index'),
+                version=params.get('version'), descent=params.get('descent'),
+                gui=params.get('gui')
+            )
+        pass
+    except Exception as err:
+        error = ExtException(parent=err)
+        print(f'\n\n{error}')
+
+
+def extract_all(product_file_name: str, product_code: str = None):
+    try:
+        products = _load_json(os.path.abspath(product_file_name))
+        if product_code:
+            products = {product_code: products[product_code]}
+            products[product_code]['disable'] = False
+        for product, params in products.items():
+            if params.get('disable'):
+                continue
+            print(f'\nРазбираем {product}\n')
+            extract(
+                params['bin'], params['src'],
+                temp_dir=params.get('temp'), index=params.get('index'),
+                version=params.get('version'), descent=params.get('descent')
+            )
+        pass
+    except Exception as err:
+        error = ExtException(parent=err)
+        print(f'\n\n{error}')
+
+
+def update_index_all(product_file_name: str, product_code: str = None, dest_dir: str = None):
+    try:
+        products = _load_json(os.path.abspath(product_file_name))
+        if product_code:
+            products = {product_code: products[product_code]}
+            products[product_code]['disable'] = False
+        for product, params in products.items():
+            if params.get('disable'):
+                continue
+            print(f'\nФормируем индекс {product}\n')
+            update_index(
+                params['src'],
+                params.get('index'),
+                dest_dir
+            )
+        pass
+    except Exception as err:
+        error = ExtException(parent=err)
+        print(f'\n\n{error}')
+
+
 def main():
     parser = argparse.ArgumentParser(
         prog=f'v8unpack {__version__}',
@@ -181,29 +243,54 @@ def main():
     parser.add_argument('--gui',
                         help="режим совместимости интерфейса 1С, переопределяет значение из исходников "
                              "для расширений, если указан устанавливается в соответствующий реквизит. "
-                             "Допустимые значения:"
-                             " допустимые значения 0 - Версия 8.2, 1 - Версия 8.2. Разрешить Такси,"
+                             "Допустимые значения: "
+                             " 0 - Версия 8.2, 1 - Версия 8.2. Разрешить Такси,"
                              " 2- Такси. Разрешить Версия 8.2, 3 - Такси"
                              "для расширений устанавливается в соответствующий реквизит")
 
+    group.add_argument('-EA', nargs=1, metavar='file',
+                       help='разобрать один или несколько файлов 1С, где '
+                            'file - путь до json файла со списком продуктов и параметрами их сборки')
+    group.add_argument('-BA', nargs=1, metavar='file',
+                       help='собрать один или несколько файлов 1С, где '
+                            'file - путь до json файла со списком продуктов и параметрами их сборки')
+
+    group.add_argument('-IA', nargs=1, metavar='file',
+                       help='сформировать index по одному или нескольким продуктам, где '
+                            'file - путь до json файла со списком продуктов и параметрами их сборки')
+
     if len(sys.argv) == 1:
         parser.print_help()
         return 1
 
     args = parser.parse_args()
-    descent = int(args.descent) if args.descent else None
     gui = args.gui if args.gui else None
 
     if args.E is not None:
         extract(os.path.abspath(args.E[0]), os.path.abspath(args.E[1]),
-                index=args.index, temp_dir=args.temp, version=args.version, descent=descent)
+                index=args.index, temp_dir=args.temp, version=args.version, descent=args.descent)
+        return
 
     if args.B is not None:
         build(os.path.abspath(args.B[0]), os.path.abspath(args.B[1]),
-              index=args.index, temp_dir=args.temp, version=args.version, descent=descent, gui=gui)
+              index=args.index, temp_dir=args.temp, version=args.version, descent=args.descent, gui=gui)
+        return
+
+    if args.BA is not None:
+        build_all(args.BA[0], args.index)
+        return
+
+    if args.EA is not None:
+        extract_all(args.EA[0], args.index)
+        return
 
     if args.I is not None:
         update_index(args.I[0], args.index, args.core)
+        return
+
+    if args.IA is not None:
+        update_index_all(args.IA[0], args.index, args.core)
+        return
 
 
 if __name__ == '__main__':
